@@ -5,7 +5,7 @@ import requests_mock
 import shapely
 
 # pylint: disable=unused-import,wrong-import-order
-from .context import Workflow
+from .context import Workflow, Job
 from .fixtures import auth_mock, auth_live, workflow_mock, workflow_live, job_mock
 import up42
 
@@ -51,6 +51,27 @@ json_workflow_tasks = {
     "error": {},
 }
 
+json_blocks = {
+    "data": [
+        {
+            "id": "4ed70368-d4e1-4462-bef6-14e768049471",
+            "name": "tiling",
+            "displayName": "Raster Tiling",
+        },
+        {
+            "id": "c0d04ec3-98d7-4183-902f-5bcb2a176d89",
+            "name": "sharpening",
+            "displayName": "Sharpening Filter",
+        },
+        {
+            "id": "a2daaab4-196d-4226-a018-a810444dcad1",
+            "name": "sobloo-s2-l1c-aoiclipped",
+            "displayName": "Sentinel-2 L1C MSI AOI clipped",
+        },
+    ],
+    "error": {},
+}
+
 
 def test_workflow_get_info(workflow_mock):
     del workflow_mock.info
@@ -143,29 +164,35 @@ def test_get_workflow_tasks_live(workflow_live):
     assert "sobloo-s2-l1c-aoiclipped:1" in list(workflow_tasks.keys())
 
 
-def test_construct_full_workflow_tasks_dict(workflow_mock):
-    input_tasks = [
-        "a2daaab4-196d-4226-a018-a810444dcad1",
-        "4ed70368-d4e1-4462-bef6-14e768049471",
-    ]
+def test_construct_full_workflow_tasks_dict_unkwown_block_raises(workflow_mock):
+    input_tasks = ["some_block"]
     with requests_mock.Mocker() as m:
         url_get_blocks = f"{workflow_mock.auth._endpoint()}/blocks"
         m.get(
-            url=url_get_blocks,
-            json={
-                "data": [
-                    {"id": "4ed70368-d4e1-4462-bef6-14e768049471", "name": "tiling"},
-                    {
-                        "id": "c0d04ec3-98d7-4183-902f-5bcb2a176d89",
-                        "name": "sharpening",
-                    },
-                    {
-                        "id": "a2daaab4-196d-4226-a018-a810444dcad1",
-                        "name": "sobloo-s2-l1c-aoiclipped",
-                    },
-                ],
-                "error": {},
-            },
+            url=url_get_blocks, json=json_blocks,
+        )
+        with pytest.raises(ValueError):
+            workflow_mock._construct_full_workflow_tasks_dict(input_tasks=input_tasks)
+
+
+@pytest.mark.parametrize(
+    "input_tasks",
+    [
+        [
+            "a2daaab4-196d-4226-a018-a810444dcad1",
+            "4ed70368-d4e1-4462-bef6-14e768049471",
+        ],
+        ["sobloo-s2-l1c-aoiclipped", "tiling"],
+        ["Sentinel-2 L1C MSI AOI clipped", "Raster Tiling",],
+        ["a2daaab4-196d-4226-a018-a810444dcad1", "tiling",],
+        ["Sentinel-2 L1C MSI AOI clipped", "4ed70368-d4e1-4462-bef6-14e768049471",],
+    ],
+)
+def test_construct_full_workflow_tasks_dict(workflow_mock, input_tasks):
+    with requests_mock.Mocker() as m:
+        url_get_blocks = f"{workflow_mock.auth._endpoint()}/blocks"
+        m.get(
+            url=url_get_blocks, json=json_blocks,
         )
         full_workflow_tasks_dict = workflow_mock._construct_full_workflow_tasks_dict(
             input_tasks=input_tasks
@@ -333,9 +360,10 @@ def test_construct_parameter_order_ids(workflow_mock):
 
 def test_run_job(workflow_mock, job_mock):
     with requests_mock.Mocker() as m:
+        job_name = f"{workflow_mock.info['name']}_py"
         job_url = (
             f"{workflow_mock.auth._endpoint()}/projects/{workflow_mock.project_id}/"
-            f"workflows/{workflow_mock.workflow_id}/jobs?name=_py"
+            f"workflows/{workflow_mock.workflow_id}/jobs?name={job_name}"
         )
         m.post(url=job_url, json={"data": {"id": job_mock.job_id}})
         input_parameters_json = (
@@ -348,7 +376,7 @@ def test_run_job(workflow_mock, job_mock):
         )
 
         jb = workflow_mock.run_job(input_parameters_json)
-        assert isinstance(jb, up42.Job)
+        assert isinstance(jb, Job)
         assert jb.job_id == job_mock.job_id
 
 
@@ -360,7 +388,7 @@ def test_test_job_live(workflow_live):
     jb = workflow_live.test_job(
         input_parameters=input_parameters_json, track_status=True
     )
-    assert isinstance(jb, up42.Job)
+    assert isinstance(jb, Job)
     with open(input_parameters_json) as src:
         job_info_params = json.load(src)
         job_info_params.update({"config": {"mode": "DRY_RUN"}})
@@ -374,12 +402,13 @@ def test_run_job_live(workflow_live):
     input_parameters_json = (
         Path(__file__).resolve().parent / "mock_data/input_params_simple.json"
     )
-    jb = workflow_live.run_job(input_parameters_json, track_status=True)
-    assert isinstance(jb, up42.Job)
+    jb = workflow_live.run_job(input_parameters_json, track_status=True, name="aa")
+    assert isinstance(jb, Job)
     with open(input_parameters_json) as src:
         assert jb.info["inputs"] == json.load(src)
         assert jb.info["mode"] == "DEFAULT"
     assert jb.get_status() == "SUCCEEDED"
+    assert jb.info["name"] == "aa_py"
 
 
 def test_get_jobs(workflow_mock):
@@ -389,7 +418,22 @@ def test_get_jobs(workflow_mock):
             f"{workflow_mock.auth._endpoint()}/projects/{workflow_mock.project_id}/jobs"
         )
         json_jobs = {
-            "data": [{"id": job_id, "status": "SUCCEEDED", "inputs": {}, "error": {},}]
+            "data": [
+                {
+                    "id": job_id,
+                    "status": "SUCCEEDED",
+                    "inputs": {},
+                    "error": {},
+                    "workflowId": "123456",
+                },
+                {
+                    "id": job_id,
+                    "status": "SUCCEEDED",
+                    "inputs": {},
+                    "error": {},
+                    "workflowId": workflow_mock.workflow_id,
+                },
+            ]
         }
         m.get(url=url_jobs, json=json_jobs)
 
@@ -401,17 +445,21 @@ def test_get_jobs(workflow_mock):
 
         jobs = workflow_mock.get_jobs()
         assert isinstance(jobs, list)
-        assert isinstance(jobs[0], up42.Job)
+        assert isinstance(jobs[0], Job)
         assert jobs[0].job_id == job_id
+        assert (
+            len(jobs) == 1
+        )  # Filters out the job that is not associated with the workflow object
 
 
 @pytest.mark.skip
 @pytest.mark.live
 def test_get_jobs_live(workflow_live):
-    # Too many jobs in test project
+    # Skip by default as too many jobs in test project, triggers too many job info requests.
     jobs = workflow_live.get_jobs()
     assert isinstance(jobs, list)
-    assert isinstance(jobs[0], up42.Job)
+    assert isinstance(jobs[0], Job)
+    assert all([j.info["workflowId"] == workflow_live.workflow_id for j in jobs])
 
 
 # TODO: Resolve
