@@ -100,47 +100,69 @@ class Workflow(Tools):
     ) -> List[Dict]:
         """
         Constructs the full workflow task definition from a simplified version.
+        Accepts blocks ids, block names, block display names & combinations of them.
 
         Args:
-            input_tasks: List of workflow task ids, see example.
+            input_tasks: List of block names, block ids, or block display names.
 
         Returns:
             The full workflow task definition.
 
         Example:
-            ```json
+            ```python
+            input_tasks = ["sobloo-s2-l1c-aoiclipped",
+                           "tiling"]
+            ```
+
+            ```python
             input_tasks = ["a2daaab4-196d-4226-a018-a810444dcad1",
                            "4ed70368-d4e1-4462-bef6-14e768049471"]
             ```
+
+            ```python
+            input_tasks = ["Sentinel-2 L1C MSI AOI clipped",
+                           "Raster Tiling"]
+            ```
         """
         full_input_tasks_definition = []
 
         # Get public + custom blocks.
         logging.getLogger("up42.tools").setLevel(logging.CRITICAL)
-        blocks_name_id: Dict = self.get_blocks(basic=True)  # type: ignore
+        blocks: Dict = self.get_blocks(basic=False)  # type: ignore
         logging.getLogger("up42.tools").setLevel(logging.INFO)
-        blocks_id_name = {
-            value: key for key, value in blocks_name_id.items()
-        }  # pylint: disable=
+
+        # Get ids of the input tasks, regardless of the specified format.
+        blocks_id_name = {block["id"]: block["name"] for block in blocks}
+        blocks_name_id = {block["name"]: block["id"] for block in blocks}
+        blocks_displaynames_id = {block["displayName"]: block["id"] for block in blocks}
+
+        input_tasks_ids = []
         for task in input_tasks:
-            if task not in blocks_id_name:
-                raise Exception(
+            if task in list(blocks_id_name.keys()):
+                input_tasks_ids.append(task)
+            elif task in list(blocks_name_id.keys()):
+                input_tasks_ids.append(blocks_name_id[task])
+            elif task in list(blocks_displaynames_id.keys()):
+                input_tasks_ids.append(blocks_displaynames_id[task])
+            else:
+                raise ValueError(
                     f"The specified input task {task} does not match any "
                     f"available block."
                 )
 
-        first_task = {
-            "name": f"{blocks_id_name[input_tasks[0]]}:1",
+        # Add first task, the data block.
+        data_task = {
+            "name": f"{blocks_id_name[input_tasks_ids[0]]}:1",
             "parentName": None,
-            "blockId": input_tasks[0],
+            "blockId": input_tasks_ids[0],
         }
+        full_input_tasks_definition.append(data_task)
+        previous_task_name = data_task["name"]
 
-        full_input_tasks_definition.append(first_task)
-        previous_task_name = first_task["name"]
-
-        # All following blocks
-        for block_id in input_tasks[1:]:
-            # Check if multiple of the same block are included.
+        # All all following (processing) blocks.
+        for block_id in input_tasks_ids[1:]:
+            # Check if multiple of the same block are in the input tasks definition,
+            # so that is does not get skipped as it has the same id.
             counts = Counter([x["blockId"] for x in full_input_tasks_definition])
             try:
                 count_block = int(counts[block_id]) + 1
@@ -156,18 +178,19 @@ class Workflow(Tools):
             previous_task_name = next_task["name"]
         return full_input_tasks_definition
 
-    def add_workflow_tasks(self, input_tasks: Union[List, List[Dict]]) -> None:
+    def add_workflow_tasks(self, input_tasks: Union[List[str], List[Dict]]) -> None:
         """
         Adds or overwrites workflow tasks in a workflow on UP42.
 
         Args:
-            input_tasks: The input tasks, can be provided in the simplified (list of block ids,
-                is automatically transformed to the full version) or full version
-                (dict of block id, block name and parent block name).
-                - Name is arbitrary but best use the block name. Always use :1 to be able to
-                    identify the order when two times the same workflow task is used.
-                - API by itself validates if the underlying block for the selected block-id is
-                    available.
+            input_tasks: The input tasks, specifying the blocks. Can be a list of the
+                block ids, block names or block display names (The name shown on the
+                [marketplace](https://marketplace.up42.com).
+
+        !!! Info
+            Using block ids specifies a specific version of the block that will be added
+            to the workflow. With block names or block display names, the most recent
+            version of a block will always be added.
 
         Example:
             ```python
@@ -175,6 +198,20 @@ class Workflow(Tools):
                                   '4ed70368-d4e1-4462-bef6-14e768049471']
             ```
 
+            ```python
+            input_tasks = ["sobloo-s2-l1c-aoiclipped", "tiling"]
+            ```
+
+            ```python
+            input_tasks = ["Sentinel-2 L1C MSI AOI clipped",
+                           "Raster Tiling"]
+
+
+        Optional: The input_tasks can also be provided as the full, detailed workflow task
+        definition (dict of block id, block name and parent block name). Always use :1
+        to be able to identify the order when two times the same workflow task is used.
+        The name is arbitrary, but best use the block name.
+
         Example:
             ```python
             input_tasks_full = [{'name': 'sobloo-s2-l1c-aoiclipped:1',
@@ -185,7 +222,6 @@ class Workflow(Tools):
                                  'blockId': '4ed70368-d4e1-4462-bef6-14e768049471'}]
             ```
         """
-        # TODO: User should be able to only provide block task names or display name.
         # Construct proper task definition from simplified input.
         if isinstance(input_tasks[0], str) and not isinstance(input_tasks[0], dict):
             input_tasks = self._construct_full_workflow_tasks_dict(input_tasks)
@@ -315,6 +351,7 @@ class Workflow(Tools):
         input_parameters: Union[Dict, str, Path] = None,
         test_job=False,
         track_status: bool = False,
+        name: str = None,
     ) -> "Job":
         """
         Helper function to create and run a new real or test job.
@@ -324,6 +361,7 @@ class Workflow(Tools):
             test_job: If set, runs a test query (search for available imagery based on your data parameters).
             track_status: Automatically attaches workflow.track_status which queries
                 the job status every 30 seconds.
+            name: The job name. Optional, by default the workflow name is assigned.
 
         Returns:
             The spawned real or test job object.
@@ -347,7 +385,9 @@ class Workflow(Tools):
 
         logger.info("Selected input_parameters: %s.", input_parameters)
 
-        name = "_py"  # Enables recognition of python API usage.
+        if name is None:
+            name = self.info["name"]
+        name = f"{name}_py"  # Temporary recognition of python API usage.
         url = (
             f"{self.auth._endpoint()}/projects/{self.project_id}/"
             f"workflows/{self.workflow_id}/jobs?name={name}"
@@ -367,6 +407,7 @@ class Workflow(Tools):
         self,
         input_parameters: Union[Dict, str, Path] = None,
         track_status: bool = False,
+        name: str = None,
     ) -> "Job":
         """
         Create a run a new test job (Test Query). With this test query you will not be
@@ -376,18 +417,23 @@ class Workflow(Tools):
             input_parameters: Either json string of workflow parameters or filepath to json.
             track_status: Automatically attaches workflow.track_status which queries
                 the job status every 30 seconds.
+            name: The job name. Optional, by default the workflow name is assigned.
 
         Returns:
             The spawned test job object.
         """
         return self._helper_run_job(
-            input_parameters=input_parameters, test_job=True, track_status=track_status
+            input_parameters=input_parameters,
+            test_job=True,
+            track_status=track_status,
+            name=name,
         )
 
     def run_job(
         self,
         input_parameters: Union[Dict, str, Path] = None,
         track_status: bool = False,
+        name: str = None,
     ) -> "Job":
         """
         Creates and runs a new job.
@@ -396,17 +442,18 @@ class Workflow(Tools):
             input_parameters: Either json string of workflow parameters or filepath to json.
             track_status: Automatically attaches workflow.track_status which queries
                 the job status every 30 seconds.
+            name: The job name. Optional, by default the workflow name is assigned.
 
         Returns:
             The spawned job object.
         """
         return self._helper_run_job(
-            input_parameters=input_parameters, track_status=track_status
+            input_parameters=input_parameters, track_status=track_status, name=name
         )
 
     def get_jobs(self, return_json: bool = False) -> Union[List["Job"], Dict]:
         """
-        Get all jobs in the specific project as job objects or json.
+        Get all jobs associated with the workflow as job objects or json.
 
         Args:
             return_json: If true, returns the job info jsons instead of job objects.
@@ -417,18 +464,23 @@ class Workflow(Tools):
         url = f"{self.auth._endpoint()}/projects/{self.project_id}/jobs"
         response_json = self.auth._request(request_type="GET", url=url)
         jobs_json = response_json["data"]
+
+        jobs_workflow_json = [
+            j for j in jobs_json if j["workflowId"] == self.workflow_id
+        ]
+
         logger.info(
             "Got %s jobs for workflow %s in project %s.",
-            len(jobs_json),
+            len(jobs_workflow_json),
             self.workflow_id,
             self.project_id,
         )
         if return_json:
-            return jobs_json
+            return jobs_workflow_json
         else:
             jobs = [
                 Job(self.auth, job_id=job["id"], project_id=self.project_id)
-                for job in tqdm(jobs_json)
+                for job in tqdm(jobs_workflow_json)
             ]
             return jobs
 
